Float (imandra-base.Imandra_prelude.Float)

`type t = float`
`module Round : sig ... end`
`val of_int : Z.t -> float`
`val of_string : string -> float`
`val (~-) : t -> t`
`val (+) : t -> t -> t`
`val (-) : t -> t -> t`
`val (*) : t -> t -> t`
`val (/) : t -> t -> t`
`val nan : t`
`val infinity : t`
`val (<) : t -> t -> bool`
`val (<=) : t -> t -> bool`
`val (>) : t -> t -> bool`
`val (>=) : t -> t -> bool`
`val (=) : t -> t -> bool`
`val (<>) : t -> t -> bool`
`val neg : t -> t`
`val abs : t -> t`
`val is_zero : t -> bool`
`val is_nan : t -> bool`
`val is_infinite : t -> bool`
`val is_normal : t -> bool`
`val is_subnormal : t -> bool`
`val is_positive : t -> bool`
`val is_negative : t -> bool`
`val min : t -> t -> t`
`val max : t -> t -> t`
`val rem : t -> t -> t`
`val sqrt : t -> t`